@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  The line input widget with chat enhanced functions
-  begin:     Tue Mar 5 2002
-  copyright: (C) 2002 by Dario Abatianni
-  email:     eisfuchs@tigress.com
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #ifndef IRCINPUT_H
@@ -19,6 +11,9 @@
 
 class KCompletionBox;
 
+/**
+ * The line input widget with chat enhanced functions
+ */
 class IRCInput : public KTextEdit
 {
     Q_OBJECT
@@ -28,9 +23,9 @@ class IRCInput : public KTextEdit
         ~IRCInput() override;
 
         void setCompletionMode(char mode);
-        char getCompletionMode();
+        char getCompletionMode() const;
         void setOldCursorPosition(int pos);
-        int getOldCursorPosition();
+        int getOldCursorPosition() const;
         QString lastCompletion() const { return m_lastCompletion; }
         void doInlineAutoreplace();
 
@@ -56,18 +51,8 @@ class IRCInput : public KTextEdit
         virtual void setOverwriteMode(bool) { }
         virtual void updateAppearance();
 
-    protected Q_SLOTS:
-        void getHistory(bool up);
-        void insertCompletion(const QString& nick);
-        void disableSpellChecking();
-        void setSpellChecking(bool set);
-
-        void maybeResize();
-
     protected:
         bool eventFilter(QObject *object,QEvent *event) override;
-        void addHistory(const QString& text);
-        bool checkPaste(QString& text);
 
         void insertFromMimeData(const QMimeData *source) override;
         void keyPressEvent(QKeyEvent* e) override;
@@ -76,6 +61,19 @@ class IRCInput : public KTextEdit
         void hideEvent(QHideEvent* e) override;
         void resizeEvent(QResizeEvent* e) override;
 
+    private:
+        void addHistory(const QString& text);
+        bool checkPaste(QString& text);
+
+    private Q_SLOTS:
+        void getHistory(bool up);
+        void insertCompletion(const QString& nick);
+        void disableSpellChecking();
+        void setSpellChecking(bool set);
+
+        void maybeResize();
+
+    private:
         QStringList historyList;
         int lineNum;
         int oldPos;
@@ -87,5 +85,7 @@ class IRCInput : public KTextEdit
 
         QTimer* m_disableSpellCheckTimer;
 
+        Q_DISABLE_COPY(IRCInput)
 };
+
 #endif
